@@ -19,12 +19,13 @@ from twisted.python import log as tlog
 from ftplib import FTP as FFTP
 from subprocess import Popen
 from os import path
-from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger
+from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars
 from uuid import uuid4
 
 
 class QFTPServer():
     def __init__(self, ip=None, port=None, username=None, password=None, mocking='', config=''):
+        self.auto_disabled = None
         self.ip = ip or '0.0.0.0'
         self.port = port or 21
         self.username = username or 'test'
@@ -36,6 +37,7 @@ class QFTPServer():
         self.config = config
         if config:
             self.logs = setup_logger(self.uuid, config)
+            set_local_vars(self,config)
         else:
             self.logs = setup_logger(self.uuid, None)
         disable_logger(1, tlog)
@@ -68,7 +70,7 @@ class QFTPServer():
 
     def run_server(self, process=False, auto=False):
         if process:
-            if auto:
+            if auto and not self.auto_disabled:
                 port = get_free_port()
                 if port > 0:
                     self.port = port
