@@ -26,7 +26,7 @@ from time import sleep
 from logging import DEBUG, getLogger
 from os import path
 from subprocess import Popen
-from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger
+from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, set_local_vars
 from uuid import uuid4
 
 #loggers = [logging.getLogger(name) for name in logging.root.manager.loggerDict]
@@ -35,6 +35,7 @@ from uuid import uuid4
 
 class QSMBServer():
     def __init__(self, ip=None, port=None, username=None, password=None, mocking=False, config=''):
+        self.auto_disabled = None
         self.ip = ip or '0.0.0.0'
         self.port = port or 445
         self.username = username or "test"
@@ -45,6 +46,7 @@ class QSMBServer():
         self.config = config
         if config:
             self.logs = setup_logger(self.uuid, config)
+            set_local_vars(self,config)
         else:
             self.logs = setup_logger(self.uuid, None)
         self.disable_logger()
@@ -85,7 +87,7 @@ class QSMBServer():
 
     def run_server(self, process=False, auto=False):
         if process:
-            if auto:
+            if auto and not self.auto_disabled:
                 port = get_free_port()
                 if port > 0:
                     self.port = port
