@@ -24,12 +24,13 @@ from tempfile import gettempdir, _get_candidate_names
 from subprocess import Popen
 from os import path
 from vncdotool import api as vncapi
-from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger
+from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars
 from uuid import uuid4
 
 
 class QVNCServer():
     def __init__(self, ip=None, port=None, username=None, password=None, mocking=False, dict_=None, config=''):
+        self.auto_disabled = None
         self.ip = ip or '0.0.0.0'
         self.port = port or 5900
         self.username = username or "test"
@@ -47,6 +48,7 @@ class QVNCServer():
         self.config = config
         if config:
             self.logs = setup_logger(self.uuid, config)
+            set_local_vars(self,config)
         else:
             self.logs = setup_logger(self.uuid, None)
         disable_logger(1, tlog)
@@ -126,7 +128,7 @@ class QVNCServer():
 
     def run_server(self, process=False, auto=False):
         if process:
-            if auto:
+            if auto and not self.auto_disabled:
                 port = get_free_port()
                 if port > 0:
                     self.port = port
